@@ -14,6 +14,7 @@ import hashlib
 import time
 import random
 import datetime
+from sklearn.metrics import silhouette_score
 
 class ml3:
     def __init__(self):
@@ -78,7 +79,6 @@ class plot:
         
         feature_mean = np.mean(X)
         feature_std = np.std(X)
-        
         X_array = X.reshape(len(X),1)
         gmm = GaussianMixture(n_components=N_COMPONENTS).fit(X_array)
         #print(gmm.get_params(True))
@@ -93,10 +93,10 @@ class plot:
         #print(gmm.covariances_)
         
         labels = gmm.predict(X_array)
-        
+        score_silhouette = silhouette_score(X_array, labels)
         plt.figure(figsize=(16, 8), dpi=100)
         plt.xlim(X_min , X_max)
-        plt.title("score=%.2f" % ( float(gmm.score(X_array))))
+        plt.title("score_silhouette=%.2f" % ( score_silhouette))
         for k in range(N_COMPONENTS):
             datask = []
             for i in range(len(labels)):
@@ -110,8 +110,10 @@ class plot:
             sns.distplot(datask, bins=feature_bins,norm_hist=True,kde=True,kde_kws={ "label": label_str})
             x,y = plot.normal_distribution(mean, std)
             plt.plot(x, y, color = "black")
-        plt.show()
-
+        datetime_str = datetime.datetime.now().strftime('%Y-%m-%d %H:%M:%S%f')
+        file_name = hashlib.md5(datetime_str.encode(encoding='UTF-8')).hexdigest()
+        plt.savefig(file_name + ".png", dpi=100)
+        return True
 
 def main():
     ml3.intro()
